<!--

    Copyright (c) 2019-present Sonatype, Inc. All rights reserved.
    Includes the third-party code listed at http://links.sonatype.com/products/nexus/attributions.
    "Sonatype" is a trademark of Sonatype, Inc.

-->
<xsl:stylesheet version="2.0"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  <xsl:output method="xml"/>

  <xsl:param name="groupId"/>
  <xsl:param name="artifactId"/>
  <xsl:param name="version"/>
  <xsl:param name="classifier"/>
  <xsl:param name="type"/>
  <xsl:param name="newVersion"/>

  <xsl:template match="@*|node()">
    <xsl:copy>
      <xsl:apply-templates select="@*|node()"/>
    </xsl:copy>
  </xsl:template>

  <!--
    lines 1: instructs the match pattern to look for dependency nodes into dependency node in pom file
    lines 2-4: match groupId, artifact and version
    lines 5: if scope is present ignore it if it is test or provided
    line  6: (classifier can be absent if empty string) or classifier matches
    line  7: extension works the same as line 6, but also considers default value of 'jar'
  -->
  <xsl:template
      match="*:dependencies/*:dependency[
              *:groupId = $groupId
              and *:artifactId = $artifactId
              and *:version = $version
              and (not(*:scope[.='test'] | *:scope[.='provided']))
              and ((not(*:classifier) and $classifier = '') or *:classifier = $classifier)
              and ((not(*:type) and ($type = '' or $type = 'jar')) or *:type = $type)
            ]/*:version/text()">
    <xsl:value-of select="$newVersion"/>
  </xsl:template>

</xsl:stylesheet>
